@@ -1,14 +1,9 @@
 package Tapper::Reports::API;
-# git description: v4.1.1-1-ga1a0e21
+# git description: v4.1.2-14-g8d0c145
 
-BEGIN {
-  $Tapper::Reports::API::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Reports::API::VERSION = '4.1.2';
-}
+our $AUTHORITY = 'cpan:TAPPER';
 # ABSTRACT: Tapper - Remote network API for result evaluation
-
+$Tapper::Reports::API::VERSION = '5.0.0';
 use 5.010;
 use strict;
 use warnings;
@@ -53,7 +48,7 @@ sub handle_download
         my %reportfilter = ();
         $reportfilter{report_id} = $report_id if $report_id;
         my $reportfile =
-         model('ReportsDB')
+         model('TestrunDB')
           ->resultset('ReportFile')
            ->search ({ %reportfilter,
                        filename  => { like => $filename } },
@@ -110,15 +105,13 @@ sub handle_upload
 {
         my ($self, $report_id, $filename, $contenttype) = @_;
 
-        my $payload = '';
-        $payload .= $_ while <STDIN>;
-
-        my $reportfile = model('ReportsDB')->resultset('ReportFile')->new({ report_id   => $report_id,
-                                                                            filename    => $filename,
-                                                                            filecontent => $payload,
-                                                                            contenttype => $contenttype || 'plain', # 'application/octet-stream',
-                                                                          });
-        $reportfile->insert;
+        my $s_filecontent = do { local $/; <STDIN> };
+        return model('TestrunDB')->resultset('ReportFile')->new({
+                report_id   => $report_id,
+                filename    => $filename,
+                filecontent => $s_filecontent,
+                contenttype => $contenttype || 'plain', # 'application/octet-stream',
+        })->insert;
 }
 
 sub _parse_args {
@@ -171,9 +164,10 @@ sub post_process_request_hook
 1; # End of Tapper::Reports::API
 
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -212,17 +206,26 @@ Handler for TT query API requests.
 
 Hook called after processing, currrently a no-op.
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
