@@ -1,11 +1,6 @@
 package Tapper::Reports::API::Daemon;
-BEGIN {
-  $Tapper::Reports::API::Daemon::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Reports::API::Daemon::VERSION = '4.1.2';
-}
-
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::Reports::API::Daemon::VERSION = '5.0.0';
 use 5.010;
 
 use strict;
@@ -13,6 +8,8 @@ use warnings;
 
 use Tapper::Reports::API;
 use Moose;
+use Tapper::Config;
+use Log::Log4perl;
 
 with 'MooseX::Daemonize';
 
@@ -24,6 +21,9 @@ after start => sub {
 
                     return unless $self->is_daemon;
 
+                    my $logconf = Tapper::Config->subconfig->{files}{log4perl_cfg};
+                    Log::Log4perl->init($logconf);
+
                     $self->initialize_server;
                     $self->server->server_loop;
                    }
@@ -63,9 +63,10 @@ sub run
 1;
 
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -79,17 +80,26 @@ Initialize and start daemon according to config.
 
 Frontend to subcommands: start, status, restart, stop.
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
   The (two-clause) FreeBSD License
 
 =cut
-
